#
# spec file for package etcd-for-k8s1.30
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define project go.etcd.io/etcd

Name:           etcd-for-k8s1.30
Version:        3.5.15
Release:        1.6
Summary:        Etcd and etcdtl for k8s image
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/etcd-io/etcd
Source:         etcd-%{version}.tar.gz
Source1:        vendor-etcdctl.tar.gz
Source2:        vendor-server.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.21
ExcludeArch:    %ix86
ExcludeArch:    s390
Conflicts:      etcd
Conflicts:      etcdctl
Provides:       etcd-for-k8s = %{version}
Conflicts:      etcd-for-k8s

%description
etcd is a distributed, consistent key-value store for shared configuration and
service discovery. This package contains different versions of etcd and
etcdctl for the kubernetes container image.

%prep
%setup -q -n etcd-%{version}

%build
%{goprep} %{project}

tar -xf %{SOURCE1} -C ./etcdctl
tar -xf %{SOURCE2} -C ./server

mkdir ./bin

cd ./etcdctl
go build -v -buildmode=pie -mod=vendor -o ../bin/etcdctl
cd ..

cd ./server
go build -v -buildmode=pie -mod=vendor -o ../bin/etcd
cd ..

%install
install -d %{buildroot}/%{_bindir}
install -d %{buildroot}/%{_sbindir}
install -D -p -m 0755 bin/etcdctl %{buildroot}%{_bindir}/etcdctl-%{version}
install -D -p -m 0755 bin/etcd %{buildroot}%{_sbindir}/etcd-%{version}

ln -sf etcdctl-%{version} %{buildroot}%{_bindir}/etcdctl
# ln -sf etcd-%{version} %{buildroot}%{_sbindir}/etcd
# we need a wrapper script to be able to set some environment variables.
echo "#!/bin/bash" > %{buildroot}%{_sbindir}/etcd
%ifarch aarch64
echo "export ETCD_UNSUPPORTED_ARCH=arm64" >> %{buildroot}%{_sbindir}/etcd
%endif
echo "exec %{_sbindir}/etcd-%{version} \"\$@\"" >> %{buildroot}%{_sbindir}/etcd
chmod 755 %{buildroot}%{_sbindir}/etcd

%files
%defattr(-,root,root)
%license LICENSE
%{_sbindir}/etcd
%{_sbindir}/etcd-%{version}
%{_bindir}/etcdctl
%{_bindir}/etcdctl-%{version}

%changelog
* Wed Oct  9 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 3.5.15:
  * Differentiate the warning message for rejected client and peer connections
  * client/v3/watch_test.go: test fmt metadata print
  * client/v3/watch.go: use fmt for metadata printing
  * Backport: fix(server/embed): enforce non-empty client TLS if scheme is https/unixs
  * fix ts with no trailing zeros
  * Remove gsutil acl command for bucket permissions.
  * dependency: bump tools/mod google.golang.org/genproto
  * dependency: bump tools/mod github.com/spf13/cobra to v1.1.3
  * dependency: bump tools/mod github.com/olekukonko/tablewriter to v0.0.5
  * dependency: bump tools/mod github.com/mattn/go-runewidth
  * dependency: bump tools/mod github.com/mattn/go-colorable
  * dependency: bump tools/mod github.com/grpc-ecosystem/grpc-gateway
  * make: Include tools/mod when checking dependency versions
  * Bump Go version to 1.21.12: GO-2024-2963 fix
  * Suppress noisy basic auth token deletion log
  * github/govuln: don't swallow govulncheck errors
  * tests/integration: deflake TestV3AuthWithLeaseRevokeWithRootJWT
  * etcd 3.5: Install shellcheck if not installed.
  * dependency: dump golang.org/x/sys to the highest version v0.18.0
  * dependency: bump github.com/modern-go/concurrent to the highest version v0.0.0-20180306012644-bacd9c7ef1dd
  * dependency: bump github.com/google/go-cmp to the highest version v0.6.0
  * Fix dependency inconsistency detection and add make verify-dep
  * dependency: bump golang.org/x/sys from v0.0.0-20210403161142-5e06dd20ab57 to v0.0.0-20220412211240-33da011f77ad
  * dependency: bump golang.org/x/net from 0.17.0 to 0.23.0
  * bugfix: register of walWriteSec
  * Support multiple values for allowed client and peer TLS identities(#18015)
  * print error log when validation on conf change failed
  * scripts/release: shallow clone repository
  * Backport removal of asset transparency workflow.
  * config: support AllowedCN and AllowedHostname through config file
  * scripts: default to using .go-version's version for tests and builds
  * .*: sync go toolchain version and add ability to verify versions
  * etcdutl: Fix snapshot restore memory alloc issue
  * server: Implement WithMmapSize option for backend config
  * Add cluster downgrade test.
  * Bump bbolt to 1.3.10 for 3.5
  * v3rpc: run health notifier to listen on online defrag state change
  * build(deps): bump distroless/static-debian11 from `046b92c` to `6d31326`
  * gRPC health server sets serving status to NOT_SERVING on defrag
  * e2e: add mix version test of adding last ver to current ver.
  * server/mvcc: should update currentRev in revMu
  * server/storage: update currentRev if scheduledCompact > currentRev
  * tests/e2e: reproduce #17780
  * server/mvcc: introduce compactBeforeSetFinishedCompact failpoint
  * Update the compaction log when bootstrap and update compact's signature
  * test: add checking snapshot be sent in mix_version_test.
  * [backport-3.5] server: ignore raft messages if member id mismatch #17078
  * add experimental-snapshot-catchup-entries flag.
  * test: add mix version e2e test.
  * feat: observe wal write at one time
  * Add approvals gh workflows.
  * [3.5]Add trivy scan as a job in release workflow
  * *: LeaseTimeToLive returns error if leader changed
  * .github: enable failpoints for integration tests
  * Bump golang.org/x/net to v0.23.0
  * Bump go-version to 1.21.9 for release-3.5 due to CVE-2023-45288
  * Backport initialization of mu in NewCtxClient to release-3.5
  * Backport updates to shellcheck ignores for release.sh script.
  * Backport rename of release script to release.sh.
  * Backport update for release script to use ssh.
  * build(deps): bump distroless/static-debian11 from `7e5c6a2` to `046b92c`
  * Fix retry requests when receiving ErrGPRCNotSupportedForLearner
  * build(deps): bump distroless/static-debian11 from `9be3fcc` to `7e5c6a2`
  * [release-3.5] backport fix watch event loss after compaction
  * Fix progress notification for watch that doesn't get any events
  * dependency: bump google.golang.org/protobuf to v1.33.0
  * dependency: bump github.com/sirupsen/logrus to v1.9.3
  * add uds test cases into e2e TestAuthority
  * Add unix socket test to TestNewURLsValue
  * pkg/types: Support Unix sockets in NewURLS
  * added dial-keepalive-time、dial-keepalive-timeout、permit-without-stream arguments to the grpc-proxy
  * Backport ignore old leader's leases revoking request
  * tests/e2e: backport e2e cluster setup
  * *: add test-smoke to the pipeline and update test-smoke
  * tools/mod: go mod tidy
  * *: fix failing shellchecks
  * server: fix comment to match function name
  * tests/e2e: implement EtcdProcess GoFailClientTimeout
  * Make CGO_ENABLED configurable for etcd 3.5
  * tests/e2e: use WaitLeader in corrupt test
  * tests/e2e: implement EtcdProcessCluster WaitLeader
  * tests/e2e: implement EtcdProcess Etcdctl
  * etcd: Add OpenBSD-specific files for SetKeepAlivePeriod handling
  * etcdserver: drain leaky goroutines before test completed
  * tests/e2e: move etcdctl to framework/e2e
  * [3.5] backport: add backoff to client config
  * [3.5] Update to go1.21
* Thu Apr 18 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Initial package version 3.5.12:
  * Version specified in kubernetes v1.30.0 - https://github.com/kubernetes/kubernetes/blob/v1.30.0/build/dependencies.yaml#L65-L87
